Files
bitvid/js/designSystem
google-labs-jules[bot]andPR0M3TH3AN 55fd791186 perf: optimize batch scope release in dynamicStyles.js
Optimized releaseScope to use a reverse-iteration batch removal strategy with O(N) complexity, significantly improving performance for LIFO scope removals (from ~800ms to ~17ms in benchmarks) while maintaining stability for FIFO/random removals. Removed unused findRuleIndex helper.

Co-authored-by: PR0M3TH3AN <[email protected]>
2026-02-05 19:41:09 +00:00
..